@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2016-09-26'; # DATE
-our $VERSION = '0.63'; # VERSION
+our $DATE = '2016-09-27'; # DATE
+our $VERSION = '0.64'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -794,13 +794,16 @@ sub _process_script {
                 my $link = ref($link0) ? $link0 : {url=>$link0};
                 my $url = $link->{url};
                 next if $seen_urls{$url}++;
-                if ($url =~ s/^pm://) {
-                    push @content, "L<$url>";
+                if ($url =~ s!^(pm|pod|prog):(//?)?!!) {
+                    push @content, "L<$url>.";
                 } else {
-                    push @content, "L<$url>";
+                    push @content, "L<$url>.";
                 }
-                push @content, ". $link->{summary}" if $link->{summary};
-                push @content, ". " .
+                if ($link->{summary}) {
+                    push @content, " $link->{summary}";
+                    push @content, "." unless $link->{summary} =~ /\.$/;
+                }
+                push @content, " " .
                     Markdown::To::POD::markdown_to_pod($link->{description})
                       if $link->{description};
                 push @content, "\n\n";
@@ -870,7 +873,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.63 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-26.
+This document describes version 0.64 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2016-09-27.
 
 =head1 SYNOPSIS
 
@@ -969,7 +972,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
 
 =head1 BUGS
 
